@@ -3,7 +3,7 @@
 # Authenticated sessions for CGI scripts
 ###########################################################
 #
-# $Id: Auth.pm 17 2004-11-12 15:16:07Z jlillich $
+# $Id: Auth.pm 5 2005-10-03 16:16:22Z jlillich $
 #
 
 package CGI::Session::Auth;
@@ -21,7 +21,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 );
 
-our $VERSION = do { my @r = (q$Revision: 1.8 $ =~ /\d+/g); sprintf "%d." . "%03d" x (scalar @r - 1), @r; };
+our $VERSION = do { q$Revision: 5 $ =~ /Revision: (\d+)/); sprintf "%d", $1; };
 
 ###########################################################
 ###
@@ -234,6 +234,19 @@ sub logout {
     $self->_info("User '", $self->{profile}{username}, "' logged out");
 }
 
+###########################################################
+
+sub uniqueUserID {
+    
+    ##
+    ## generate a unique 32-character user ID
+    ##
+    
+    my ($username) = @_;
+    
+    return md5_hex(localtime, $username);
+}
+
 ###########################################################
 ###
 ### backend specific methods
@@ -371,15 +384,15 @@ sub _cgi {
 
 ###########################################################
 
-sub uniqueUserID {
-    
+sub _encpw {
+
     ##
-    ## generate a unique 32-character user ID
+    ## encrypt password
     ##
     
-    my ($username) = @_;
-    
-    return md5_hex(localtime, $username);
+    my ($self, $password) = @_;
+
+    return md5_hex($password);
 }
 
 ###########################################################
@@ -432,7 +445,6 @@ __END__
 CGI::Session::Auth - Authenticated sessions for CGI scripts
 
 
-
 =head1 ABSTRACT
 
 CGI::Session::Auth is a Perl class that provides the necessary
@@ -441,7 +453,6 @@ for session management and supports several backends for
 user and group data storage.
 
 
-
 =head1 SYNOPSIS
 
   use CGI;
@@ -467,7 +478,6 @@ user and group data storage.
   }
 
 
-
 =head1 DESCRIPTION
 
 CGI::Session::Auth offers an alternative to HTTP
@@ -492,9 +502,9 @@ no real storage backend (only the user 'guest' with password 'guest'
 may log in). See its subclasses for real implementations.
 
 
-
 =head1 METHODS
 
+
 =head2 new(\%parameters)
 
 This is the class constructor. The hash referenced by C<\%parameters> must contain
@@ -520,9 +530,12 @@ Additionally, the following optional parameters are possible:
 
 Try to authenticate the visitor by his IP address. (Default: 0)
 
-=item LoginVarPrefix
+=item lvprefix
 
-A string the names of the login form fields begin with. (Default. 'log_')
+By default, CGI::Session::Auth expects the username and password of
+the visitor to be passed in the form variables 'log_username' and
+'log_password'. To avoid conflicts, the prefix 'log_' can be altered
+by this parameter.
 
 =item Log
 
@@ -531,51 +544,71 @@ module and gets its logger object calling Log::Log4perl->get_logger('CGI::Sessio
 
 =back
 
+
 =head2 authenticate()
 
 This method does the actual authentication. It fetches session information to determine the
 authentication status of the current visitor and further checks if form variables
 from a proceeding login form have been set and eventually performs a login attempt.
+
+This login attempt is done by calling the method _login() (see below).
+
 If authentication succeeded neither by session data nor login information, and the
 parameter C<IPAuth> is set to a true value, it tries to authenticate the visitor by his
 IP address.
 
+
+=head2 _login()
+
+This virtual method performs the actual login attempt by comparing the
+login form data the visitor sent with some local user database. The _login method
+of the base class CGI::Session::Auth only knows the user 'guest' with password 'guest'.
+
+To access a real user database, you have to use a subclass that
+modifies the _login method appropriately. See the modules in the Auth/
+subdirectory.
+
+
 =head2 sessionCookie()
 
 For the session to be persistent across page requests, its session ID has to be
 stored in a cookie. This method returns the correct cookie (as generated by CGI::cookie()),
 but it remains the duty of the CGI application to send it.
 
+
 =head2 loggedIn()
 
 Returns a boolean value representing the current visitors authentication
 status.
 
+
 =head2 logout()
 
 Discards the current visitors authentication status.
 
+
 =head2 hasUsername($username)
 
 Checks if a certain user is logged in.
 
+
 =head2 isGroupMember($groupname)
 
 Checks if the current user is a member of a certain user group.
 
+
 =head2 profile($key [, $value])
 
 Returns the user profile field identified by C<$key>. If C<$value> is given,
 it will be stored in the respective profile field first.
 
 
-
 =head1 BUGS
 
 There's always one to be squished.
 
 Assistance in the development of this modules is encouraged and
-greatly appreciated! Please contact me at L<jochen@lillich.info>.
+greatly appreciated. Please contact me!
 
 
 
@@ -584,11 +617,11 @@ greatly appreciated! Please contact me at L<jochen@lillich.info>.
 Don't get me started...
 
 
-
 =head1 SEE ALSO
 
 L<CGI::Session>
 
+
 =head1 AUTHOR
 
 Jochen Lillich, E<lt>jochen@lillich.infoE<gt>
@@ -603,13 +636,14 @@ These people have helped in the development of this module:
 =item Cees Hek
 =item Daniel Brunkhorst
 =item Gregory Ramsperger
+=item Jess Robinson
 
 =back
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003-2004 by Jochen Lillich
+Copyright (c) 2003-2005 by Jochen Lillich
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
